@@ -1,7 +1,6 @@
-"""memocell - An exact modelling framework for stochastic processes with and
-without memory in Python."""
+"""memocell - Bayesian inference of stochastic cellular processes with and without memory in Python."""
 
-__version__ = '0.1.0'
+__version__ = '0.1.3'
 __author__ = 'Maurice Langhinrichs <m.langhinrichs@icloud.com>'
 
 # __all__ applies to importing with "from memocell import *"
